# chaqum

The [ˈkeɪkjuːm] job manager handles job queues and the closely
associated workload of process spawning, log managment and interprocess
messaging. It tries to be unixy and powerful while keeping complexity
and the learning curve as low as possible.

Documentation is available as man pages. Start by reading
[chaqum(1)](https://wagnerflo.github.io/chaqum/chaqum.1.html).
